# Hardware

You can [install](../install/install) Theengs Gateway on various hardware as long as they have a Bluetooth Low Energy (BLE) module.

The project is primarily developed for Linux, with the Raspberry Pi as a reference platform.

It also runs on other platforms, but unsupported:

* Windows: untested
* macOS: limited by some peculiarities in Apple's Core Bluetooth framework

That said, if you encounter an issue on any platform, we do our best to fix it.

If you want to use Theengs on cheaper and more portable hardware, you can use [OpenMQTTGateway](https://docs.openmqttgateway.com/) with an ESP32.
